==> li-pagador-1.0.3.tar.gz: li-pagador-1.0.3/src/api_pagador/urls.py <==
# -*- coding: utf-8 -*-


def registrar():
    from api_pagador import recursos
    from api_pagador.app import api
    api.add_resource(recursos.HelloWorld, '/hello-world/')
    api.add_resource(recursos.FormasPagamentoResource, '/formas-pagamento/')
    api.add_resource(recursos.FormaPagamentoResource, '/forma-pagamento/<int:pagamento_id>/')
    api.add_resource(recursos.FormaPagamentoConfiguracaoResource, '/forma-pagamento/<int:pagamento_id>/configuracao/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoScriptResource, '/forma-pagamento/<int:pagamento_id>/script/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoSelecaoResource, '/forma-pagamento/<int:pagamento_id>/selecao/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoIntegracaoResource, '/forma-pagamento/<int:pagamento_id>/integracao/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoInstalacaoResource, '/forma-pagamento/<int:pagamento_id>/instalacao/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoConfiguracaoEnviarResource, '/forma-pagamento/<int:pagamento_id>/configuracao/<int:conta_id>/pedido/<int:pedido_numero>/enviar')
    api.add_resource(recursos.FormaPagamentoRetornoResource,
                     '/forma-pagamento/<int:pagamento_id>/retorno',
                     '/forma-pagamento/<int:pagamento_id>/retorno/<string:tipo>/',
                     '/forma-pagamento/<int:pagamento_id>/conta/<int:conta_id>/retorno',
                     '/forma-pagamento/<int:pagamento_id>/conta/<int:conta_id>/retorno/<string:tipo>/')

==> li-pagador-1.1.24.tar.gz: li-pagador-1.1.24/src/api_pagador/urls.py <==
# -*- coding: utf-8 -*-


def registrar():
    from api_pagador import recursos
    from api_pagador.app import api
    api.add_resource(recursos.HelloWorld, '/hello-world/')
    api.add_resource(recursos.FormasPagamentoResource, '/formas-pagamento/')
    api.add_resource(recursos.FormaPagamentoResource, '/forma-pagamento/<int:pagamento_id>/')
    api.add_resource(recursos.FormaPagamentoConfiguracaoResource, '/forma-pagamento/<int:pagamento_id>/configuracao/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoConfiguracaoComplementoResource, '/forma-pagamento/<int:pagamento_id>/configuracao/<int:conta_id>/complemento')
    api.add_resource(recursos.FormaPagamentoScriptResource, '/forma-pagamento/<int:pagamento_id>/script/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoSelecaoResource, '/forma-pagamento/<int:pagamento_id>/selecao/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoIntegracaoResource, '/forma-pagamento/<int:pagamento_id>/integracao/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoInstalacaoResource, '/forma-pagamento/<int:pagamento_id>/instalacao/<int:conta_id>/')
    api.add_resource(recursos.FormaPagamentoConfiguracaoEnviarResource, '/forma-pagamento/<int:pagamento_id>/configuracao/<int:conta_id>/pedido/<int:pedido_numero>/enviar')
    api.add_resource(recursos.FormaPagamentoRetornoResource,
                     '/forma-pagamento/<int:pagamento_id>/retorno',
                     '/forma-pagamento/<int:pagamento_id>/retorno/<string:tipo>/',
                     '/forma-pagamento/<int:pagamento_id>/conta/<int:conta_id>/retorno',
                     '/forma-pagamento/<int:pagamento_id>/conta/<int:conta_id>/retorno/<string:tipo>/')
